@@ -116,6 +116,7 @@ func TestLoadBalancerCreate(t *testing.T) {
 				Deny:  []string{"cidr:1.2.0.0/16"},
 				Allow: []string{"ip:1.2.3.4", "ip:1.2.3.5"},
 			},
+			Network: "EXTERNAL",
 		}
 		disableLetsEncryptDNSRecords := true
 		r.DisableLetsEncryptDNSRecords = &disableLetsEncryptDNSRecords
@@ -135,6 +136,7 @@ func TestLoadBalancerCreate(t *testing.T) {
 		config.Doit.Set(config.NS, doctl.ArgHTTPIdleTimeoutSeconds, 120)
 		config.Doit.Set(config.NS, doctl.ArgDenyList, []string{"cidr:1.2.0.0/16"})
 		config.Doit.Set(config.NS, doctl.ArgAllowList, []string{"ip:1.2.3.4", "ip:1.2.3.5"})
+		config.Doit.Set(config.NS, doctl.ArgLoadBalancerNetwork, "EXTERNAL")
 
 		err := RunLoadBalancerCreate(config)
 		assert.NoError(t, err)
@@ -182,6 +184,7 @@ func TestLoadBalancerCreateGLB(t *testing.T) {
 				"019cb059-603f-4828-8be4-641a20f25006",
 				"023da268-bc81-468f-aa4d-9abdc4f69935",
 			},
+			Network: "EXTERNAL",
 		}
 		disableLetsEncryptDNSRecords := true
 		r.DisableLetsEncryptDNSRecords = &disableLetsEncryptDNSRecords
@@ -203,6 +206,7 @@ func TestLoadBalancerCreateGLB(t *testing.T) {
 			"019cb059-603f-4828-8be4-641a20f25006",
 			"023da268-bc81-468f-aa4d-9abdc4f69935",
 		})
+		config.Doit.Set(config.NS, doctl.ArgLoadBalancerNetwork, "EXTERNAL")
 
 		err := RunLoadBalancerCreate(config)
 		assert.NoError(t, err)
